==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/TailwindConfig.java <==
package io.github.cdklabs.projen.web;

/**
 * (experimental) Declares a Tailwind CSS configuration file.
 * <p>
 * There are multiple ways to add Tailwind CSS in your node project - see:
 * https://tailwindcss.com/docs/installation
 * <p>
 * @see PostCss
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:29.074Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.TailwindConfig")
public class TailwindConfig extends software.amazon.jsii.JsiiObject {

    protected TailwindConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TailwindConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TailwindConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.TailwindConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TailwindConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.TailwindConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.TailwindConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.web.TailwindConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * Default: "tailwind.config.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options().fileName(fileName);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.web.TailwindConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.TailwindConfig build() {
            return new io.github.cdklabs.projen.web.TailwindConfig(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.web.TailwindConfigOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.web.TailwindConfigOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/TailwindConfig.java <==
package io.github.cdklabs.projen.web;

/**
 * (experimental) Declares a Tailwind CSS configuration file.
 * <p>
 * There are multiple ways to add Tailwind CSS in your node project - see:
 * https://tailwindcss.com/docs/installation
 * <p>
 * @see <a href="PostCss">PostCss</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.762Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.TailwindConfig")
public class TailwindConfig extends software.amazon.jsii.JsiiObject {

    protected TailwindConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TailwindConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TailwindConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.TailwindConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TailwindConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.TailwindConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.TailwindConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.web.TailwindConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * Default: "tailwind.config.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options().fileName(fileName);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.web.TailwindConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.TailwindConfig build() {
            return new io.github.cdklabs.projen.web.TailwindConfig(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.web.TailwindConfigOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.web.TailwindConfigOptions.Builder();
            }
            return this.options;
        }
    }
}
